Git taxbreak
------------

.. image:: https://github.com/kamil1b/git-taxbreak/workflows/Master/badge.svg

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black

.. image:: https://api.codeclimate.com/v1/badges/6ad9e9549fdf496138c6/maintainability
   :target: https://codeclimate.com/github/kamil1b/git-taxbreak/maintainability
   :alt: Maintainability

.. image:: https://codecov.io/gh/kamil1b/git-taxbreak/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/kamil1b/git-taxbreak

Tool for collect artifacts from git for register creative work

Install
-------

.. code-block:: sh

   pip install git+https://github.com/kamil1b/git-taxbreak.git
